@@ -44,7 +44,11 @@ static size_t peakDocSize = 0;
 
 typedef double (TheengsDecoder::*decoder_function)(const char* data_str,
                                                    int offset, int data_length,
-                                                   bool reverse, bool canBeNegative);
+                                                   bool reverse, bool canBeNegative, bool isFloat);
+
+typedef double (TheengsDecoder::*staticbitdecoder_function)(const char* data_str,
+                                                            const char* source_str, int offset, int bitindex,
+                                                            const char* falseresult, const char* trueresult);
 
 /*
  * @brief Revert the string data 2 by 2 to get the correct endianness
@@ -62,10 +66,10 @@ void TheengsDecoder::reverse_hex_data(const char* in, char* out, int l) {
 
 double TheengsDecoder::bf_value_from_hex_string(const char* data_str,
                                                 int offset, int data_length,
-                                                bool reverse, bool canBeNegative) {
+                                                bool reverse, bool canBeNegative, bool isFloat) {
   DEBUG_PRINT("extracting BCF data\n");
 
-  long value = (long)value_from_hex_string(data_str, offset, data_length, reverse, false);
+  long value = (long)value_from_hex_string(data_str, offset, data_length, reverse, false, false);
   double d_value = ((((value >> 8) * 100) + (uint8_t)value)) / 100.0;
 
   if (canBeNegative) {
@@ -82,17 +86,25 @@ double TheengsDecoder::bf_value_from_hex_string(const char* data_str,
  */
 double TheengsDecoder::value_from_hex_string(const char* data_str,
                                              int offset, int data_length,
-                                             bool reverse, bool canBeNegative) {
-  DEBUG_PRINT("offset: %d, len %d, rev %u, neg, %u\n",
-              offset, data_length, reverse, canBeNegative);
+                                             bool reverse, bool canBeNegative, bool isFloat) {
+  DEBUG_PRINT("offset: %d, len %d, rev %u, neg, %u, flo, %u\n",
+              offset, data_length, reverse, canBeNegative, isFloat);
   std::string data(&data_str[offset], data_length);
 
   if (reverse) {
     reverse_hex_data(&data_str[offset], &data[0], data_length);
   }
 
-  double value = strtol(data.c_str(), NULL, 16);
-  DEBUG_PRINT("extracted value from %s = 0x%08lx\n", data.c_str(), (long)value);
+  double value = 0;
+  if (!isFloat) {
+    value = strtol(data.c_str(), NULL, 16);
+    DEBUG_PRINT("extracted value from %s = 0x%08lx\n", data.c_str(), (long)value);
+  } else {
+    long longV = strtol(data.c_str(), NULL, 16);
+    float floatV = *((float *) &longV);
+    DEBUG_PRINT("extracted float value from %s = %f\n", data.c_str(), floatV);
+    value = floatV;
+  }
 
   if (canBeNegative) {
     if (data_length <= 2 && value > SCHAR_MAX) {
@@ -149,6 +161,16 @@ int TheengsDecoder::data_length_is_valid(size_t data_len, size_t default_min,
   return -1;
 }
 
+uint8_t TheengsDecoder::getBinaryData(char ch) {
+  uint8_t data = 0;
+  if (ch >= '0' && ch <= '9')
+    data = ch - '0';
+  else if (ch >= 'a' && ch <= 'f')
+    data = 10 + (ch - 'a');
+
+  return data;
+}
+
 bool TheengsDecoder::checkDeviceMatch(const JsonArray& condition,
                                       const char* svc_data,
                                       const char* mfg_data,
@@ -218,9 +240,9 @@ bool TheengsDecoder::checkDeviceMatch(const JsonArray& condition,
 
       if (strstr(cond_str, "contain") != nullptr) {
         if (strstr(cmp_str, condition[++i].as<const char*>()) != nullptr) {
-          match = true;
+          match = true; // (strstr(cond_str, "not_") != nullptr) ? false : true;
         } else {
-          match = false;
+          match = false; // (strstr(cond_str, "not_") != nullptr) ? true : false;
         }
         i++;
       } else if (strstr(cond_str, "index") != nullptr) {
@@ -325,16 +347,8 @@ bool TheengsDecoder::checkPropCondition(const JsonArray& prop_condition,
         size_t cond_len = strlen(prop_condition[i + 2 + inverse].as<const char*>());
         if (strstr((const char*)prop_condition[i + 2], "bit") != nullptr) {
           char ch = *(data_src + prop_condition[i + 1].as<int>());
-          uint8_t data = 0;
-          if (ch >= '0' && ch <= '9')
-            data = ch - '0';
-          else if (ch >= 'a' && ch <= 'f')
-            data = 10 + (ch - 'a');
-          else if (ch >= 'A' && ch <= 'F')
-            data = 10 + (ch - 'F');
-          else
-            return false;
-        
+          uint8_t data = getBinaryData(ch);
+
           uint8_t shift = prop_condition[i + 3].as<uint8_t>();
           uint8_t val = prop_condition[i + 4].as<uint8_t>();
           if (((data >> shift) & 0x01) == val) {
@@ -441,7 +455,8 @@ int TheengsDecoder::decodeBLEJson(JsonObject& jsondata) {
               temp_val = (this->*dec_fun)(src, decoder[2].as<int>(),
                                           decoder[3].as<int>(),
                                           decoder[4].as<bool>(),
-                                          decoder[5].isNull() ? true : decoder[5].as<bool>());
+                                          decoder[5].isNull() ? true : decoder[5].as<bool>(),
+                                          decoder[6].isNull() ? false : decoder[6].as<bool>());
 
             } else {
               break;
@@ -542,11 +557,27 @@ int TheengsDecoder::decodeBLEJson(JsonObject& jsondata) {
             success = i_main;
             DEBUG_PRINT("found value = %s : %.2f\n", _key.c_str(), jsondata[_key].as<double>());
           } else if (strstr((const char*)decoder[0], "static_value") != nullptr) {
-            if (prop.containsKey("is_bool") && !decoder[1].is<std::string>()) {
-              decoder[1] = (bool)decoder[1];
+            if (strstr((const char*)decoder[0], "bit") != nullptr) {
+              JsonArray staticbitdecoder = prop["decoder"];
+              const char* data_src = nullptr;
+
+              if (svc_data && strstr((const char*)staticbitdecoder[1], SVC_DATA) != nullptr) {
+                data_src = svc_data;
+              } else if (mfg_data && strstr((const char*)staticbitdecoder[1], MFG_DATA) != nullptr) {
+                data_src = mfg_data;
+              }
+
+              char ch = *(data_src + staticbitdecoder[2].as<int>());
+              uint8_t data = getBinaryData(ch);
+              uint8_t shift = staticbitdecoder[3].as<uint8_t>();
+              int x = 4 + ((data >> shift) & 0x01);
+
+              jsondata[sanitizeJsonKey(kv.key().c_str())] = staticbitdecoder[x];
+              success = i_main;
+            } else {
+              jsondata[sanitizeJsonKey(kv.key().c_str())] = decoder[1];
+              success = i_main;
             }
-            jsondata[sanitizeJsonKey(kv.key().c_str())] = decoder[1];
-            success = i_main;
           } else if (strstr((const char*)decoder[0], "string_from_hex_data") != nullptr) {
             const char* src = svc_data;
             if (strstr((const char*)decoder[1], MFG_DATA)) {
